@@ -58,6 +58,9 @@
 #endif /* NEXTSTEP3_HPPA */
 /* in ansi string.h but undefined in -posix */
 #define bzero(b,len) memset(b,0,len)
+#ifndef FD_CLOEXEC
+#define FD_CLOEXEC	1
+#endif
 #define SIZEOF_IS_LONG_INT
 #define HAVE_GETRUSAGE
 #define PATH_TMP        "/private/tmp"
