@@ -7,6 +7,7 @@
 #include <signal.h>
 #include <time.h>
 #include <assert.h>
+#include <syslog.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
 #include <sys/un.h>
@@ -35,6 +36,7 @@ static void open_seedfile(const char *seedfile)
     fprintf(stderr, "Could not open %s: %s\n", seedfile, strerror(errno));
     exit(EXIT_FAILURE);
   }
+  close_on_exec(randsavefd, 1);
 
   /*
    * The contents of the seedfile may be sensitive, since we start seeding
@@ -177,8 +179,9 @@ static void killpeer(int service_socket)
 
 static void usage(const char *progname)
 {
+  fprintf(stderr, "prngd %s (%s)\n", PRNGD_VERSION, PRNGD_DATE);
   fprintf(stderr,
-	  "Usage: %s [options] /path/to/socket1 [/path/to/socket2 ...]\nOptions:\n\t-d/--debug: debugging on\n\t-c/--cmdfile cmdpath: use cmdpath for entropy commands [%s]\n\t-s/--seedfile seedpath: use seedpath as seedfile [%s]\n\t-n/--no-seedfile: no seedfile, keep pool in memory only\n\t-k/--kill: kill daemon on other side\n",
+	  "Usage: %s [options] /path/to/socket1 [/path/to/socket2 ...]\nOptions:\n\t-d/--debug: debugging on\n\t-c/--cmdfile cmdpath: use cmdpath for entropy commands [%s]\n\t-s/--seedfile seedpath: use seedpath as seedfile [%s]\n\t-n/--no-seedfile: no seedfile, keep pool in memory only\n\t-k/--kill: kill daemon on other side\n\t-v/--version: print version and exit\n",
 	  progname, CONFIGFILE, RANDSAVENAME);
 }
 
@@ -206,7 +209,11 @@ int main(int argc, char *argv[])
   argp = 1;
   while (argp < argc)
   {
-    if (!strcmp(argv[argp], "-d") || !strcmp(argv[argp], "--debug"))
+    if (!strcmp(argv[argp], "-v") || !strcmp(argv[argp], "--version")) {
+      fprintf(stdout, "prngd %s (%s)\n", PRNGD_VERSION, PRNGD_DATE);
+      exit(EXIT_SUCCESS);
+    }
+    else if (!strcmp(argv[argp], "-d") || !strcmp(argv[argp], "--debug"))
       debug = 1;
     else if ((!strcmp(argv[argp], "-c") || !strcmp(argv[argp], "--cmdfile"))
 	     && (argp + 1 < argc))
@@ -416,6 +423,7 @@ int main(int argc, char *argv[])
 	      strerror(errno));
       exit(EXIT_FAILURE);
     }
+    close_on_exec(service_socket[i], 1);
   }
 
   if (killmode) {
