@@ -3,8 +3,10 @@
 #include <sys/time.h>
 #include <sys/times.h>
 #include <unistd.h>
+#include <fcntl.h>
 
 #include "config.h"
+#include "prngd_version.h"
 
 #ifdef HAVE_GETRUSAGE
 #include <sys/resource.h>
@@ -73,3 +75,4 @@ void SHA1_final(SHA1_CTX *ctx);
 void SHA1_digest(SHA1_CTX *ctx, unsigned char *s);
 void SHA1_copy(SHA1_CTX *dest, SHA1_CTX *src);
 
+void close_on_exec(int fd, int on);
