@@ -321,9 +321,9 @@ void main_loop(int *service_socket, int numsock, struct sockaddr_un sockun,
 	fprintf(stderr, "Spawned gatherer: %s (%s",
 		entropy_source[gatherer_entry].path,
 		entropy_source[gatherer_entry].args[0]);
-	for (i = 1; i < 5; i++)
-	  if (entropy_source[gatherer_entry].args[i])
-	    fprintf(stderr, " %s", entropy_source[gatherer_entry].args[i]);
+	i = 1;
+	while ((i < 5) && (entropy_source[gatherer_entry].args[i]))
+	  fprintf(stderr, " %s", entropy_source[gatherer_entry].args[i++]);
 	fprintf(stderr, ")\n");
       }
       continue;
@@ -523,6 +523,7 @@ void main_loop(int *service_socket, int numsock, struct sockaddr_un sockun,
 	  close(accept_fd);
 	  continue;
         }
+	close_on_exec(accept_fd, 1);
 
         /*
          * Create a new structure for the incoming request 
